@@ -2,6 +2,7 @@ from django.contrib.syndication.views import Feed
 from django.shortcuts import get_object_or_404
 from newscenter.models import Article, Newsroom
 
+
 class NewsroomFeed(Feed):
     def get_object(self, request, newsroom, website=None):
         try:
@@ -20,3 +21,6 @@ class NewsroomFeed(Feed):
 
     def items(self, obj):
         return Article.objects.get_published().filter(newsroom=obj)
+
+    def item_pubdate(self, item):
+        return item.release_date
