@@ -1,16 +1,20 @@
 from django import template
 from django.template import Library, Node
-from django.db.models import get_model
 from newscenter.models import Category
 
 register = Library()
 
+
 class FeaturedNode(Node):
     def __init__(self, newsroom):
         self.newsroom = template.Variable(newsroom)
 
     def render(self, context):
         try:
+            from django.apps import apps
+            model = apps.get_model('newscenter', 'Newsroom')
+        except ImportError:
+            from django.db.models import get_model
             model = get_model('newscenter', 'Newsroom')
         except:
             raise template.TemplateSyntaxError("Failed to retrieve model")
@@ -34,6 +38,7 @@ class FeaturedNode(Node):
 
     get_news = register.tag(get_news)
 
+
 class CategoryNode(Node):
     def render(self, context):
         try:
